@@ -7,7 +7,7 @@
 
     our $USES_MITE    = "Mite::Role";
     our $MITE_SHIM    = "Mite::Shim";
-    our $MITE_VERSION = "0.009003";
+    our $MITE_VERSION = "0.010001";
 
     BEGIN {
         require Scalar::Util;
@@ -76,7 +76,8 @@
         return if $type ne 'Mite::Class';
 
         my @missing_methods;
-        @missing_methods = grep( !$target->can($_), "compilation_stages" )
+        @missing_methods = grep( !$target->can($_),
+            "_compile_meta_method", "compilation_stages" )
           and croak( "$me requires $target to implement methods: " . join q[, ],
             @missing_methods );
 
